From 5ee2e650a4d9d1599bd4cbc31557ea31076784f7 Mon Sep 17 00:00:00 2001
From: Paul Eggert <eggert@cs.ucla.edu>
Date: Wed, 9 Nov 2016 17:45:24 -0800
Subject: [PATCH] Make 'memory-limit' obsolete

* doc/lispref/internals.texi (Garbage Collection):
Do not document memory-limit.
* etc/NEWS: Document this.
* lisp/emacs-lisp/byte-opt.el (side-effect-free-fns):
Remove memory-limit.
* lisp/subr.el (memory-limit): Now obsolete.
* src/alloc.c (Fmemory_limit): Always return 0.
---
 doc/lispref/internals.texi  | 14 --------------
 etc/NEWS                    |  4 ++++
 lisp/emacs-lisp/byte-opt.el |  2 +-
 lisp/subr.el                |  3 +++
 src/alloc.c                 | 15 ++-------------
 5 files changed, 10 insertions(+), 28 deletions(-)

diff --git a/doc/lispref/internals.texi b/doc/lispref/internals.texi
index fedef3d..670d6a5 100644
--- a/doc/lispref/internals.texi
+++ b/doc/lispref/internals.texi
@@ -501,20 +501,6 @@ Garbage Collection
 proportion.
 @end defopt
 
-  The value returned by @code{garbage-collect} describes the amount of
-memory used by Lisp data, broken down by data type.  By contrast, the
-function @code{memory-limit} provides information on the total amount of
-memory Emacs is currently using.
-
-@defun memory-limit
-This function returns the address of the last byte Emacs has allocated,
-divided by 1024.  We divide the value by 1024 to make sure it fits in a
-Lisp integer.
-
-You can use this to get a general idea of how your actions affect the
-memory usage.
-@end defun
-
 @defvar memory-full
 This variable is @code{t} if Emacs is nearly out of memory for Lisp
 objects, and @code{nil} otherwise.
diff --git a/etc/NEWS b/etc/NEWS
index 197a694..6a9c9ea 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -527,6 +527,10 @@ mode bindings: 'C-c @ C-a', 'C-c @ C-t', 'C-c @ C-d', and 'C-c @ C-e.'
 before running.  This is controlled by the 'grep-save-buffers'
 variable.
 
+** The 'memory-limit' function now always returns 0, and is now
+declared obsolete.  Its value has been useless or misleading for quite
+some time.
+
 ** Some obsolete functions, variables, and faces have been removed:
 *** From subr.el: window-dot, set-window-dot, read-input, show-buffer,
 eval-current-buffer, string-to-int
diff --git a/lisp/emacs-lisp/byte-opt.el b/lisp/emacs-lisp/byte-opt.el
index 610c3b6..92ecc5e 100644
--- a/lisp/emacs-lisp/byte-opt.el
+++ b/lisp/emacs-lisp/byte-opt.el
@@ -1249,7 +1249,7 @@ byte-optimize-set
 	 keymapp
 	 line-beginning-position line-end-position list listp
 	 make-marker mark mark-marker markerp max-char
-	 memory-limit minibuffer-window
+	 minibuffer-window
 	 mouse-movement-p
 	 natnump nlistp not null number-or-marker-p numberp
 	 one-window-p overlayp
diff --git a/lisp/subr.el b/lisp/subr.el
index b23f605..683e510 100644
--- a/lisp/subr.el
+++ b/lisp/subr.el
@@ -1293,6 +1293,9 @@ posn-object-width-height
 
 (make-obsolete 'forward-point "use (+ (point) N) instead." "23.1")
 (make-obsolete 'buffer-has-markers-at nil "24.3")
+(make-obsolete 'memory-limit
+               "use (alist-get \\='vsize (process-attributes (emacs-pid))) for virtual memory size."
+               "26.1")
 
 ;; bug#23850
 (make-obsolete 'string-to-unibyte   "use `encode-coding-string'." "25.2")
diff --git a/src/alloc.c b/src/alloc.c
index 90c6f94..be70908 100644
--- a/src/alloc.c
+++ b/src/alloc.c
@@ -7048,21 +7048,10 @@ or memory information can't be obtained, return nil.  */)
 /* Debugging aids.  */
 
 DEFUN ("memory-limit", Fmemory_limit, Smemory_limit, 0, 0, 0,
-       doc: /* Return the address of the last byte Emacs has allocated, divided by 1024.
-This may be helpful in debugging Emacs's memory usage.
-We divide the value by 1024 to make sure it fits in a Lisp integer.  */)
+       doc: /* Return zero.  */)
   (void)
 {
-  Lisp_Object end;
-
-#if defined HAVE_NS || !HAVE_SBRK
-  /* Avoid warning.  sbrk has no relation to memory allocated anyway.  */
-  XSETINT (end, 0);
-#else
-  XSETINT (end, (intptr_t) (char *) sbrk (0) / 1024);
-#endif
-
-  return end;
+  return make_number (0);
 }
 
 DEFUN ("memory-use-counts", Fmemory_use_counts, Smemory_use_counts, 0, 0, 0,
-- 
2.7.4

